@@ -1,10 +1,10 @@
 try:
     # For Python 3.0 and later
-    from urllib.request import urlopen
+    from urllib.request import urlopen, Request
     from urllib.parse import urlencode
 except ImportError:
     # Fall back to Python 2 urllib2
-    from urllib2 import urlopen
+    from urllib2 import urlopen, Request
     from urllib import urlencode
 import logging
 import socket
@@ -19,7 +19,7 @@ log = logging.getLogger(__name__)
 class HipchatMessage(object):
     default_color = 'red'
 
-    def __init__(self, msg_type, inputs, token, user, room_id, notify, api_host):
+    def __init__(self, msg_type, inputs, token, user, room_id, notify, api_host, api_version):
         self.type = msg_type
         self.inputs = inputs
         self.inputs_list = [inp.strip() for inp in self.inputs.split('|')]
@@ -28,10 +28,18 @@ class HipchatMessage(object):
         self.room_id = room_id
         self.notify = notify
         self.host = api_host or 'api.hipchat.com'
-        self.url = 'https://{0}/v1/rooms/message'.format(self.host)
+        self.api_version = api_version
+        self.urlv1 = 'https://{0}/v1/rooms/message'.format(self.host)
+        self.urlv2 = 'https://{0}/v2/room/{1}/notification'.format(self.host, self.room_id)
         self.message_color = 'gray'
+        if str(self.api_version) != "2":
+            self.url = self.urlv1
+            self.deliver_payload = self.deliver_payload_v1
+        else:
+            self.url = self.urlv2
+            self.deliver_payload = self.deliver_payload_v2
 
-    def deliver_payload(self, **kwargs):
+    def deliver_payload_v1(self, **kwargs):
         """
         Makes HTTP GET request to HipChat containing the message from nagios
         according to API Documentation https://www.hipchat.com/docs/api/method/rooms/message
@@ -46,7 +54,7 @@ class HipchatMessage(object):
         message.update(kwargs)
         message_params = urlencode(message)
         message_params = message_params.encode('utf-8')
-        raw_response = urlopen(self.url, message_params)
+        raw_response = urlopen(self.urlv1, message_params)
         response_data = json.load(raw_response)
         if 'error' in response_data:
             error_message = response_data['error'].get('message')
@@ -57,6 +65,33 @@ class HipchatMessage(object):
             log.error('Unexpected response')
         return raw_response
 
+    def deliver_payload_v2(self, **kwargs):
+        """
+        Makes HTTP POST request to HipChat containing the message from nagios
+        according to API Documentation https://hipchat.corvisa.com/docs/apiv2/method/send_room_notification
+        """
+        message_body = self.render_message()
+        message = {'message': message_body,
+                   'color': self.message_color,
+                   'notify': True if int(self.notify) > 0 else False,
+                   'message_format': 'html'}
+        message_params = json.dumps(message)
+        message_params = message_params.encode('utf-8')
+        headers = {'Authorization': 'Bearer {0}'.format(self.token),
+                   'Content-Type': 'application/json'}
+        request = Request(self.urlv2, message_params, headers)
+        raw_response = urlopen(request)
+        if raw_response.getcode() / 100 != 2:
+            response_data = json.load(raw_response)
+            if 'error' in response_data:
+                error_message = response_data['error'].get('message')
+                error_type = response_data['error'].get('type')
+                error_code = response_data['error'].get('code')
+                log.error('%s - %s: %s', error_code, error_type, error_message)
+            elif not 'status' in response_data:
+                log.error('Unexpected response')
+        return raw_response
+
     def get_host_context(self):
         hostname, timestamp, ntype, hostaddress, state, hostoutput = self.inputs_list
         return {'hostname': hostname, 'timestamp': timestamp, 'ntype': ntype,
